@@ -177,13 +177,14 @@ class Spider(SpiderHook):
             except:
                 from asyncpy import settings
                 self.settings_attr = get_attrs(settings)
-                raise Exception("import settings error,please check path or project")
+                lg = get_logger()
+                lg.warning("【import settings Not Found,Please check path or project】")
+                lg.warning("【import settings Not Found,Please check path or project】")
         else:
             self.settings_attr = get_attrs(self.settings_attr)
             self.concurrency = self.settings_attr.get('CONCURRENT_REQUESTS')
 
 
-
         # set logger
         if isinstance(self.settings_attr,dict) and self.settings_attr.get('LOG_FILE'):
             LOG_FILE, LOG_LEVEL = self.settings_attr.get('LOG_FILE'),self.settings_attr.get('LOG_LEVEL','INFO')
@@ -196,7 +197,6 @@ class Spider(SpiderHook):
             self.logger = check_logger(name=self.name)
 
 
-
         if not self.concurrency:
             self.concurrency = settings.CONCURRENT_REQUESTS
 
@@ -309,10 +309,11 @@ class Spider(SpiderHook):
                     signal, lambda: asyncio.ensure_future(self.stop(signal))
                 )
             except NotImplementedError:
-                self.logger.warning(
-                    f"{self.name} tried to use loop.add_signal_handler "
-                    "but it is not implemented on this platform."
-                )
+                # self.logger.warning(
+                #     f"{self.name} tried to use loop.add_signal_handler "
+                #     "but it is not implemented on this platform."
+                # )
+                ...
         # Run hook before spider start crawling
         await self._run_spider_hook(after_start)
 
